# User Guide

In this section we provide material how to use xradar.

Most of the material is distributed as jupyter notebooks to be able to interactively explore xradar functionality.

To use xradar in a project:

```python
import xradar
```

```{toctree}
:maxdepth: 2
:caption: Get started

datamodel
importers
exporters
notebooks/Accessors
```

```{toctree}
:maxdepth: 2
:caption: Examples

notebooks/CfRadial1_Model_Transformation
notebooks/CfRadial1
notebooks/CfRadial1_Export
notebooks/ODIM_H5
notebooks/GAMIC
notebooks/Furuno
notebooks/Rainbow
notebooks/Iris
notebooks/HaloPhotonics
notebooks/MRR
notebooks/NexradLevel2
notebooks/Read-plot-Sigmet-data-from-AWS
notebooks/plot-ppi
notebooks/angle_reindexing
notebooks/Multi-Volume-Concatenation.ipynb
notebooks/multiple-sweeps-into-volume-scan.ipynb
```
